@@ -884,7 +884,7 @@ class DiffusionPriorNetwork(nn.Module):
 
         if remainder > 0:
             text_encodings = F.pad(text_encodings, (0, 0, 0, remainder), value = 0.)
-            mask = F.pad(mask, (0, remainder), value = 0.)
+            mask = F.pad(mask, (0, remainder), value = False)
 
         null_text_embeds = self.null_text_embed.to(text_encodings.dtype)
 
